aboutsummaryrefslogtreecommitdiffstats
path: root/themes/default/js/ui/jquery.ui.selectable.js
diff options
context:
space:
mode:
authorpatdenice <patdenice@piwigo.org>2011-10-28 13:25:54 +0000
committerpatdenice <patdenice@piwigo.org>2011-10-28 13:25:54 +0000
commit2a5be28bc5a0fe4748279bebe23d1be6416fe015 (patch)
tree19dc0a131baa6ad1b8fb1c96e64c153013785d81 /themes/default/js/ui/jquery.ui.selectable.js
parent3ea95e0ebcce5ecd80ac4e95879dae72e9360988 (diff)
feature:2487
Update jQuery to 1.6.4 and jQuery UI to 1.8.16 git-svn-id: http://piwigo.org/svn/trunk@12525 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'themes/default/js/ui/jquery.ui.selectable.js')
-rw-r--r--themes/default/js/ui/jquery.ui.selectable.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/themes/default/js/ui/jquery.ui.selectable.js b/themes/default/js/ui/jquery.ui.selectable.js
index 9ada93b96..0b8f9b6f2 100644
--- a/themes/default/js/ui/jquery.ui.selectable.js
+++ b/themes/default/js/ui/jquery.ui.selectable.js
@@ -1,5 +1,5 @@
/*
* jQuery UI Selectable 1.8.10
*
* Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
@@ -260,7 +260,7 @@ $.widget("ui.selectable", $.ui.mouse, {
});
$.extend($.ui.selectable, {
- version: "1.8.10"
+ version: "1.8.16"
});
})(jQuery);
@@ -1,5 +1,5 @@
/*
- * jQuery UI Selectable 1.8.10
+ * jQuery UI Selectable 1.8.16
*
* Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)